@@ -53,7 +53,7 @@ pub(crate) fn draw_frame(
         subaction,
         frame_index,
         camera,
-    ); // 2.5ms
+    );
 
     let uniform_size = mem::size_of::<Matrix4<f32>>();
     let size_padded = 256;
@@ -86,19 +86,18 @@ pub(crate) fn draw_frame(
                     Some(framebuffer)
                 },
                 ops: wgpu::Operations {
-                    load: wgpu::LoadOp::Clear(wgpu::Color {
-                        r: 0.0,
-                        g: 0.0,
-                        b: 0.0,
-                        a: 1.0,
-                    }),
+                    load: wgpu::LoadOp::Clear(state.background_color),
                     store: true,
                 },
             }],
             depth_stencil_attachment: None,
             label: None,
         });
-        rpass.set_pipeline(&state.render_pipeline);
+        if wireframe {
+            rpass.set_pipeline(&state.render_pipeline_line);
+        } else {
+            rpass.set_pipeline(&state.render_pipeline_fill);
+        }
 
         for (i, draw) in draws.iter().enumerate() {
             rpass.set_bind_group(0, &state.bind_groups[i], &[]);
@@ -141,9 +140,9 @@ fn create_draws(
     let fov_rad = fov * consts::PI / 180.0;
 
     let camera_offset = Vector3::new(
-        camera.radius * camera.phi.sin() * camera.theta.sin(),
-        camera.radius * camera.phi.cos(),
-        camera.radius * camera.phi.sin() * camera.theta.cos(),
+        camera.radius() * camera.phi.sin() * camera.theta.sin(),
+        camera.radius() * camera.phi.cos(),
+        camera.radius() * camera.phi.sin() * camera.theta.cos(),
     );
     let camera_location = camera.target + camera_offset;
     let view = Matrix4::look_at_rh(camera_location, camera.target, Vector3::new(0.0, 1.0, 0.0));
@@ -161,10 +160,10 @@ fn create_draws(
         }
 
         cgmath::ortho(
-            -width / 2.0,
-            width / 2.0,
-            -height / 2.0,
-            height / 2.0,
+            -width / 2.0 * camera.radius_mult,
+            width / 2.0 * camera.radius_mult,
+            -height / 2.0 * camera.radius_mult,
+            height / 2.0 * camera.radius_mult,
             -1000.0,
             1000.0,
         )
@@ -175,24 +174,24 @@ fn create_draws(
 
     for hurt_box in &frame.hurt_boxes {
         let color = if hurt_box.state.is_intangible() {
-            [0.0, 0.0, 1.0, 0.3]
+            [0.0, 0.0, 1.0, 0.15]
         } else if hurt_box.state.is_invincible() {
-            [0.0, 1.0, 0.0, 0.3]
+            [0.0, 1.0, 0.0, 0.15]
         } else {
             match invulnerable_type {
-                InvulnerableType::Hit => [1.0, 1.0, 0.0, 0.3],
+                InvulnerableType::Hit => [1.0, 1.0, 0.0, 0.15],
                 InvulnerableType::Grab => {
                     if hurt_box.hurt_box.grabbable {
-                        [1.0, 1.0, 0.0, 0.3]
+                        [1.0, 1.0, 0.0, 0.15]
                     } else {
-                        [0.0, 0.0, 1.0, 0.3]
+                        [0.0, 0.0, 1.0, 0.15]
                     }
                 }
                 InvulnerableType::TrapItem => {
                     if hurt_box.hurt_box.trap_item_hittable {
-                        [1.0, 1.0, 0.0, 0.3]
+                        [1.0, 1.0, 0.0, 0.15]
                     } else {
-                        [0.0, 0.0, 1.0, 0.3]
+                        [0.0, 0.0, 1.0, 0.15]
                     }
                 }
             }
@@ -219,12 +218,12 @@ fn create_draws(
         }
 
         let color = match hitbox.hitbox_id {
-            0 => [0.93725, 0.39216, 0.00000, 0.3], // orange
-            1 => [1.00000, 0.00000, 0.00000, 0.3], // red
-            2 => [1.00000, 0.00000, 1.00000, 0.3], // purple
-            3 => [0.09412, 0.83922, 0.78823, 0.3], // turqoise
-            4 => [0.14118, 0.83992, 0.09412, 0.3], // green
-            _ => [1.00000, 1.00000, 1.00000, 0.3], // white
+            0 => [0.93725, 0.39216, 0.00000, 0.2], // orange
+            1 => [1.00000, 0.00000, 0.00000, 0.2], // red
+            2 => [1.00000, 0.00000, 1.00000, 0.2], // purple
+            3 => [0.09412, 0.83922, 0.78823, 0.2], // turqoise
+            4 => [0.14118, 0.83992, 0.09412, 0.2], // green
+            _ => [1.00000, 1.00000, 1.00000, 0.2], // white
         };
 
         let next = Vector3::new(hitbox.next_pos.x, hitbox.next_pos.y, hitbox.next_pos.z);
